==> jsp4sakura-0.0.1.tar.gz: jsp/sample/sample1.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 *
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *  Copyright (C) 2005 by Embedded and Real-Time Systems Laboratory
 *              Graduate School of Information Science, Nagoya Univ., JAPAN
 *
 *  嵭Ԥϡʲ (1)(4) ξ狼Free Software Foundation 
 *  ˤäƸɽƤ GNU General Public License  Version 2 ˵
 *  ҤƤ˸¤ꡤܥեȥܥեȥ
 *  ѤΤޤࡥʲƱˤѡʣѡۡʰʲ
 *  ѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơŬѲǽ
 *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
 *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
 *
 *  @(#) $Id: sample1.h,v 1.36 2007/05/08 07:43:52 honda Exp $
 */

/*
 *  ץץ(1)Υإåե
 */

#include <t_services.h>

/*
 *  ƥͥ٤
 */

#define MAIN_PRIORITY	5		/* ᥤ󥿥ͥ */
					/* HIGH_PRIORITY ⤯뤳 */

#define HIGH_PRIORITY	9		/* ˼¹Ԥ륿ͥ */
#define MID_PRIORITY	10
#define LOW_PRIORITY	11

/*
 *  åȰ¸CPU㳰ϥɥεưˡʤɡ
 */

#ifdef M68K

#define CPUEXC1		5		/* 㳰 */
#define RAISE_CPU_EXCEPTION	syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)

#elif defined(SH3)

#define CPUEXC1		224		/* ɥ顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))

#elif defined(SH1)

#define CPUEXC1		9		/* CPUɥ쥹顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))
#ifdef TOKIWA_SH1
#define	STACK_SIZE	512		/* Υå */
#endif /* TOKIWA_SH1 */

#elif defined(ARMV4)

#define CPUEXC1		4		/* ɥ顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))

#elif defined(V850)

#elif defined(H8)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */

#elif defined(H8S)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define LOOP_REF	4000L		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(MICROBLAZE)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define STACK_SIZE	2048		/* Υå */

#elif defined(IA32)

#define CPUEXC1		0		/* 㳰 */
#define RAISE_CPU_EXCEPTION   syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)
#define OMIT_VGET_TIM

#elif defined(TMS320C54X)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define STACK_SIZE	320		/* Υå */
#define LOOP_REF	500000L		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(XSTORMY16)

#define CPUEXC1		0		/* ̵̿㳰 */
#define RAISE_CPU_EXCEPTION	__asm__( ".hword 0x0006" )
#define OMIT_VGET_TIM			/* vxget_tim()󥵥ݡ */
#define LOOP_REF 	4000L		/* ®ٷ¬ѤΥ롼ײ */
#define STACK_SIZE	256		/* Υå */
#define TASK_PORTID	1		/* SIOϥݡ1Ѥ */

#elif defined(MIPS3) || defined(MIPS64)

#define CPUEXC1     Bp      /* ֥졼ݥ㳰ʥȯ */
#define RAISE_CPU_EXCEPTION   syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)

#elif defined(M16C) && defined(OAKS16)

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 2       /* ʸϤ륷ꥢݡID */

#elif defined(M16C) && defined(OAKS16_MINI)

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  384     /* Υå */
#define TASK_PORTID 2       /* ʸϤ륷ꥢݡID */

#elif defined(M16C) && defined(M3029) 

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 1       /* ʸϤ륷ꥢݡID */

#elif defined(LINUX)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define OMIT_VGET_TIM
#define LOOP_REF	4000000		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(NIOS2)

#define CPUEXC1		0		  /* ̤̿㳰 */
#define RAISE_CPU_EXCEPTION	  Asm("div zero, zero, zero");

#elif defined(M32C)

#define CPUEXC1 32 /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm(" int #32") /* եȥȯ */
#define STACK_SIZE 512 /* Υå */
#define TASK_PORTID 1 /* ʸϤ륷ꥢݡID */ 

#elif defined(M32R)

#define CPUEXC1 EXC_TRAP00
#define RAISE_CPU_EXCEPTION Asm("trap 0")

#elif defined(TLCS_900) && defined(ZUP_F16_EX)

#define CPUEXC1     3      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION Asm("   swi 2") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 1       /* ʸϤ륷ꥢݡID */
#define OMIT_VGET_TIM

#elif defined(__lm32__)

#define CPUEXC1              5 
#define RAISE_CPU_EXCEPTION  syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)
#define STACK_SIZE           512 
#define LOOP_REF	         500000

#endif

/*
 *  åȤ˰¸ǽΤ
 */

#ifndef TASK_PORTID
#define	TASK_PORTID	1		/* ʸϤ륷ꥢݡID */
#endif /* TASK_PORTID */

#ifndef STACK_SIZE
#define	STACK_SIZE	8192		/* Υå */
#endif /* STACK_SIZE */

#ifndef LOOP_REF
#define LOOP_REF	1000000		/* ®ٷ¬ѤΥ롼ײ */
#endif /* LOOP_REF */

/*
 *  ؿΥץȥ
 */
#ifndef _MACRO_ONLY

extern void	task(VP_INT tskno);
extern void	main_task(VP_INT exinf);
extern void	tex_routine(TEXPTN texptn, VP_INT tskno);
extern void	cyclic_handler(VP_INT exinf);
extern void	cpuexc_handler(VP p_excinf);

#endif /* _MACRO_ONLY */

==> jsp4sakura-0.0.2.tar.gz: jsp/sample/sample1.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 *
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *  Copyright (C) 2005 by Embedded and Real-Time Systems Laboratory
 *              Graduate School of Information Science, Nagoya Univ., JAPAN
 *
 *  嵭Ԥϡʲ (1)(4) ξ狼Free Software Foundation 
 *  ˤäƸɽƤ GNU General Public License  Version 2 ˵
 *  ҤƤ˸¤ꡤܥեȥܥեȥ
 *  ѤΤޤࡥʲƱˤѡʣѡۡʰʲ
 *  ѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơŬѲǽ
 *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
 *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
 *
 *  @(#) $Id: sample1.h,v 1.36 2007/05/08 07:43:52 honda Exp $
 */

/*
 *  ץץ(1)Υإåե
 */

#include <t_services.h>

/*
 *  ƥͥ٤
 */

#define MAIN_PRIORITY	5		/* ᥤ󥿥ͥ */
					/* HIGH_PRIORITY ⤯뤳 */

#define HIGH_PRIORITY	9		/* ˼¹Ԥ륿ͥ */
#define MID_PRIORITY	10
#define LOW_PRIORITY	11

/*
 *  åȰ¸CPU㳰ϥɥεưˡʤɡ
 */

#ifdef M68K

#define CPUEXC1		5		/* 㳰 */
#define RAISE_CPU_EXCEPTION	syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)

#elif defined(SH3)

#define CPUEXC1		224		/* ɥ顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))

#elif defined(SH1)

#define CPUEXC1		9		/* CPUɥ쥹顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))
#ifdef TOKIWA_SH1
#define	STACK_SIZE	512		/* Υå */
#endif /* TOKIWA_SH1 */

#elif defined(ARMV4)

#define CPUEXC1		4		/* ɥ顼㳰 */
#define RAISE_CPU_EXCEPTION	(*((volatile int *) 0xFFFFFEC1))

#elif defined(V850)

#elif defined(H8)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */

#elif defined(H8S)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define LOOP_REF	4000L		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(MICROBLAZE)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define STACK_SIZE	2048		/* Υå */

#elif defined(IA32)

#define CPUEXC1		0		/* 㳰 */
#define RAISE_CPU_EXCEPTION   syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)
#define OMIT_VGET_TIM

#elif defined(TMS320C54X)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define STACK_SIZE	320		/* Υå */
#define LOOP_REF	500000L		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(XSTORMY16)

#define CPUEXC1		0		/* ̵̿㳰 */
#define RAISE_CPU_EXCEPTION	__asm__( ".hword 0x0006" )
#define OMIT_VGET_TIM			/* vxget_tim()󥵥ݡ */
#define LOOP_REF 	4000L		/* ®ٷ¬ѤΥ롼ײ */
#define STACK_SIZE	256		/* Υå */
#define TASK_PORTID	1		/* SIOϥݡ1Ѥ */

#elif defined(MIPS3) || defined(MIPS64)

#define CPUEXC1     Bp      /* ֥졼ݥ㳰ʥȯ */
#define RAISE_CPU_EXCEPTION   syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)

#elif defined(M16C) && defined(OAKS16)

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 2       /* ʸϤ륷ꥢݡID */

#elif defined(M16C) && defined(OAKS16_MINI)

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  384     /* Υå */
#define TASK_PORTID 2       /* ʸϤ륷ꥢݡID */

#elif defined(M16C) && defined(M3029) 

#define CPUEXC1     32      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm("   int #32") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 1       /* ʸϤ륷ꥢݡID */

#elif defined(LINUX)

#undef CPUEXC1				/* CPU㳰ϥɥ򥵥ݡȤʤ */
#define OMIT_VGET_TIM
#define LOOP_REF	4000000		/* ®ٷ¬ѤΥ롼ײ */

#elif defined(NIOS2)

#define CPUEXC1		0		  /* ̤̿㳰 */
#define RAISE_CPU_EXCEPTION	  Asm("div zero, zero, zero");

#elif defined(M32C)

#define CPUEXC1 32 /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm(" int #32") /* եȥȯ */
#define STACK_SIZE 512 /* Υå */
#define TASK_PORTID 1 /* ʸϤ륷ꥢݡID */ 

#elif defined(M32R)

#define CPUEXC1 EXC_TRAP00
#define RAISE_CPU_EXCEPTION Asm("trap 0")

#elif defined(TLCS_900) && defined(ZUP_F16_EX)

#define CPUEXC1     3      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION Asm("   swi 2") /* եȥȯ */
#define STACK_SIZE  512     /* Υå */
#define TASK_PORTID 1       /* ʸϤ륷ꥢݡID */
#define OMIT_VGET_TIM

#elif defined(__lm32__)

#define CPUEXC1              5 
#define RAISE_CPU_EXCEPTION  syslog(LOG_NOTICE, "zerodiv = %d", 10 / 0)
#define STACK_SIZE           512 
#define LOOP_REF	         500000

#elif defined(__RX__)

#define CPUEXC1     0      /* CPU㳰ϥɥֹ */
#define RAISE_CPU_EXCEPTION asm(" int #0") /* եȥȯ */

#endif

/*
 *  åȤ˰¸ǽΤ
 */

#ifndef TASK_PORTID
#define	TASK_PORTID	1		/* ʸϤ륷ꥢݡID */
#endif /* TASK_PORTID */

#ifndef STACK_SIZE
#define	STACK_SIZE	8192		/* Υå */
#endif /* STACK_SIZE */

#ifndef LOOP_REF
#define LOOP_REF	1000000		/* ®ٷ¬ѤΥ롼ײ */
#endif /* LOOP_REF */

/*
 *  ؿΥץȥ
 */
#ifndef _MACRO_ONLY

extern void	task(VP_INT tskno);
extern void	main_task(VP_INT exinf);
extern void	tex_routine(TEXPTN texptn, VP_INT tskno);
extern void	cyclic_handler(VP_INT exinf);
extern void	cpuexc_handler(VP p_excinf);

#endif /* _MACRO_ONLY */
